@@ -1,5 +1,5 @@
-import typing as t
-from typing import overload
+from __future__ import annotations
+from typing import overload, TypeVar, Any, Dict
 from .rfc7515.model import (
     JWSAlgModel,
     HeaderMember,
@@ -83,10 +83,10 @@ register_algorithms()
 
 def serialize_compact(
         protected: Header,
-        payload: t.Union[bytes, str],
+        payload: bytes | str,
         private_key: KeyFlexible,
-        algorithms: t.Optional[t.List[str]] = None,
-        registry: t.Optional[JWSRegistry] = None) -> str:
+        algorithms: list[str] | None = None,
+        registry: JWSRegistry | None = None) -> str:
     """Generate a JWS Compact Serialization. The JWS Compact Serialization
     represents digitally signed or MACed content as a compact, URL-safe
     string, per Section 7.1.
@@ -121,8 +121,8 @@ def serialize_compact(
 def validate_compact(
         obj: CompactSignature,
         public_key: KeyFlexible,
-        algorithms: t.Optional[t.List[str]] = None,
-        registry: t.Optional[JWSRegistry] = None) -> bool:
+        algorithms: list[str] | None = None,
+        registry: JWSRegistry | None = None) -> bool:
     """Validate the JWS Compact Serialization with the given key.
     This method is usually used together with ``extract_compact``.
 
@@ -144,10 +144,10 @@ def validate_compact(
 
 
 def deserialize_compact(
-        value: t.Union[bytes, str],
+        value: bytes | str,
         public_key: KeyFlexible,
-        algorithms: t.Optional[t.List[str]] = None,
-        registry: t.Optional[JWSRegistry] = None) -> CompactSignature:
+        algorithms: list[str] | None = None,
+        registry: JWSRegistry | None = None) -> CompactSignature:
     """Extract and validate the JWS Compact Serialization (in string, or bytes)
     with the given key. An JWE Compact Serialization looks like:
 
@@ -175,29 +175,29 @@ def deserialize_compact(
 
 @overload
 def serialize_json(
-        members: t.List[HeaderDict],
-        payload: t.Union[bytes, str],
+        members: list[HeaderDict],
+        payload: bytes | str,
         private_key: KeyFlexible,
-        algorithms: t.Optional[t.List[str]] = None,
-        registry: t.Optional[JWSRegistry] = None) -> GeneralJSONSerialization: ...
+        algorithms: list[str] | None = None,
+        registry: JWSRegistry | None = None) -> GeneralJSONSerialization: ...
 
 
 @overload
 def serialize_json(
         members: HeaderDict,
-        payload: t.Union[bytes, str],
+        payload: bytes | str,
         private_key: KeyFlexible,
-        algorithms: t.Optional[t.List[str]] = None,
-        registry: t.Optional[JWSRegistry] = None) -> FlattenedJSONSerialization: ...
+        algorithms: list[str] | None = None,
+        registry: JWSRegistry | None = None) -> FlattenedJSONSerialization: ...
 
 
 def serialize_json(
-        members: t.Union[HeaderDict, t.List[HeaderDict]],
-        payload: t.Union[bytes, str],
+        members: HeaderDict | list[HeaderDict],
+        payload: bytes | str,
         private_key: KeyFlexible,
-        algorithms: t.Optional[t.List[str]] = None,
-        registry: t.Optional[JWSRegistry] = None,
-) -> t.Union[GeneralJSONSerialization, FlattenedJSONSerialization]:
+        algorithms: list[str] | None = None,
+        registry: JWSRegistry | None = None,
+) -> GeneralJSONSerialization | FlattenedJSONSerialization:
     """Generate a JWS JSON Serialization (in dict). The JWS JSON Serialization
     represents digitally signed or MACed content as a JSON object. This representation
     is neither optimized for compactness nor URL-safe.
@@ -227,7 +227,9 @@ def serialize_json(
     if registry is None:
         registry = construct_registry(algorithms)
 
-    find_key = lambda d: guess_key(private_key, d, True)
+    def find_key(obj: Any) -> Key:
+        return guess_key(private_key, obj, True)
+
     _payload = to_bytes(payload)
     if isinstance(members, list):
         return sign_general_json(members, _payload, registry, find_key)
@@ -239,24 +241,24 @@ def serialize_json(
 def deserialize_json(
         value: GeneralJSONSerialization,
         public_key: KeyFlexible,
-        algorithms: t.Optional[t.List[str]] = None,
-        registry: t.Optional[JWSRegistry] = None) -> GeneralJSONSignature: ...
+        algorithms: list[str] | None = None,
+        registry: JWSRegistry | None = None) -> GeneralJSONSignature: ...
 
 
 @overload
 def deserialize_json(
         value: FlattenedJSONSerialization,
         public_key: KeyFlexible,
-        algorithms: t.Optional[t.List[str]] = None,
-        registry: t.Optional[JWSRegistry] = None) -> FlattenedJSONSignature: ...
+        algorithms: list[str] | None = None,
+        registry: JWSRegistry | None = None) -> FlattenedJSONSignature: ...
 
 
 def deserialize_json(
-        value: t.Union[GeneralJSONSerialization, FlattenedJSONSerialization],
+        value: GeneralJSONSerialization | FlattenedJSONSerialization,
         public_key: KeyFlexible,
-        algorithms: t.Optional[t.List[str]] = None,
-        registry: t.Optional[JWSRegistry] = None,
-) -> t.Union[GeneralJSONSignature, FlattenedJSONSignature]:
+        algorithms: list[str] | None = None,
+        registry: JWSRegistry | None = None,
+) -> GeneralJSONSignature | FlattenedJSONSignature:
     """Extract and validate the JWS (in string) with the given key.
 
     :param value: a dict of the JSON signature
@@ -269,7 +271,9 @@ def deserialize_json(
     if registry is None:
         registry = construct_registry(algorithms)
 
-    find_key = lambda d: guess_key(public_key, d)
+    def find_key(obj: Any) -> Key:
+        return guess_key(public_key, obj)
+
     if "signatures" in value:
         general_obj = extract_general_json(value)
         if not verify_general_json(general_obj, registry, find_key):
@@ -282,7 +286,7 @@ def deserialize_json(
         return flattened_obj
 
 
-DetachValue = t.TypeVar("DetachValue", str, t.Dict[str, t.Any])
+DetachValue = TypeVar("DetachValue", str, Dict[str, Any])
 
 
 def detach_content(value: DetachValue) -> DetachValue:
